windows

package
v0.0.0-...-1873eae Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2025 License: Apache-2.0 Imports: 30 Imported by: 0

Documentation

Rendered for windows/amd64

Index

Constants

const (
	// LayerCimPathFlag is the option flag used to represent the path at which a layer
	// CIM must be stored. This flag only applies if an image layer is being extracted
	// onto the snapshot i.e the snapshot key has an UnpackKeyPrefix. For all other
	// snapshots, this MUST be ignored.
	LayerCimPathFlag = "cimpath="

	// Similar to ParentLayerPathsFlag this is the optinos flag used to represent the JSON encoded list of
	// parent layer CIMs
	ParentLayerCimPathsFlag = "parentCimPaths="

	// string to specify the standard cimfs type of mount
	CimFSMountType string = "CimFS"

	// string to specify the block CIM type of mount
	BlockCIMMountType string = "BlockCIM"

	// a flag that specifies the type of a block CIM in case of BlockCIM mounts
	BlockCIMTypeFlag string = "blockCIMType="
)

Variables

This section is empty.

Functions

func GetCimPath

func GetCimPath(m *mount.Mount) (string, error)

Only applies to a snapshot created for image extraction, for such a snapshot provides the path to a cim in which image layer will be extracted.

func GetParentCimPaths

func GetParentCimPaths(m *mount.Mount) ([]string, error)

gets the paths of the parent cims of this mount

func NewCimFSSnapshotter

func NewCimFSSnapshotter(root string) (snapshots.Snapshotter, error)

NewCimFSSnapshotter returns a new CimFS based windows snapshotter

func NewWindowsSnapshotter

func NewWindowsSnapshotter(root string) (snapshots.Snapshotter, error)

NewWindowsSnapshotter returns a new windows snapshotter

Types

This section is empty.

Jump to